==> jvim_3.0-2.0.orig.tar.gz: jvim-3.0-2.0.orig/src/msdos.h <==
/* vi:ts=4:sw=4
 *
 * VIM - Vi IMproved		by Bram Moolenaar
 *
 * Read the file "credits.txt" for a list of people who contributed.
 * Read the file "uganda.txt" for copying and usage conditions.
 */

/*
 * MSDOS Machine-dependent things.
 */

/*
 * Names for the EXRC, HELP and temporary files.
 * Some of these may have been defined in the makefile.
 */

#ifndef SYSVIMRC_FILE
# ifdef notdef	/* ken */
#  define SYSVIMRC_FILE	"$VIM\\_vimrc"
# else
#  define SYSVIMRC_FILE	"$HOME\\_vimrc"
# endif
#endif

#ifndef SYSEXRC_FILE
# ifdef notdef	/* ken */
#  define SYSEXRC_FILE	"$VIM\\_exrc"
# else
#  define SYSEXRC_FILE	"$HOME\\_exrc"
# endif
#endif

#ifndef VIMRC_FILE
# define VIMRC_FILE		"_vimrc"
#endif

#ifndef EXRC_FILE
# define EXRC_FILE		"_exrc"
#endif

#ifndef VIM_HLP
# ifdef notdef	/* ken */
#  define VIM_HLP		"$VIM\\vim.hlp"
# else
#  define VIM_HLP		"$HOME\\vim.hlp"
# endif
#endif

#ifndef notdef
# ifndef BACKUPDIR
#  define BACKUPDIR		"$HOME"
# endif
#endif

#ifndef DEF_DIR
# ifndef notdef	/* ken */
#  define DEF_DIR		"$TMP"
# else
#  define DEF_DIR		"c:\\tmp"
# endif
#endif

#define TMPNAME1		"viXXXXXX"		/* put it in current dir */
#define TMPNAME2		"voXXXXXX"		/*  is there a better place? */
#define TMPNAMELEN		10

#ifndef MAXMEM
# define MAXMEM			256				/* use up to 256Kbyte for buffer */
#endif
#ifndef MAXMEMTOT
# define MAXMEMTOT		0				/* decide in set_init */
#endif

#ifdef NT
# define BASENAMELEN	250				/* length of base of file name */
#else
# define BASENAMELEN	8				/* length of base of file name */
#endif

/*
 * MSDOS Machine-dependent routines.
 */

#ifdef remove
# undef remove                   /* MSDOS remove()s when not readonly */
#endif
#define remove vim_remove

/* use chdir() that also changes the default drive */
#define chdir vim_chdir

==> jvim_3.0-2.1a.orig.tar.gz: jvim-3.0-2.1a.orig/src/msdos.h <==
/* vi:ts=4:sw=4
 *
 * VIM - Vi IMproved		by Bram Moolenaar
 *
 * Read the file "credits.txt" for a list of people who contributed.
 * Read the file "uganda.txt" for copying and usage conditions.
 */

/*
 * MSDOS Machine-dependent things.
 */

/*
 * Names for the EXRC, HELP and temporary files.
 * Some of these may have been defined in the makefile.
 */

#ifndef SYSVIMRC_FILE
# ifdef notdef	/* ken */
#  define SYSVIMRC_FILE	"$VIM\\_vimrc"
# else
#  define SYSVIMRC_FILE	"$HOME\\_vimrc"
# endif
#endif

#ifndef SYSEXRC_FILE
# ifdef notdef	/* ken */
#  define SYSEXRC_FILE	"$VIM\\_exrc"
# else
#  define SYSEXRC_FILE	"$HOME\\_exrc"
# endif
#endif

#ifndef VIMRC_FILE
# define VIMRC_FILE		"_vimrc"
#endif

#ifndef EXRC_FILE
# define EXRC_FILE		"_exrc"
#endif

#ifndef DEFVIMRC_FILE /* ken */
# define DEFVIMRC_FILE	"$VIM\\vimrc"
#endif

#ifndef VIM_HLP
# define VIM_HLP		"$VIM\\vim.hlp"
#endif

#ifndef notdef
# ifndef BACKUPDIR
#  define BACKUPDIR		"$HOME"
# endif
#endif

#ifndef DEF_DIR
# ifndef notdef	/* ken */
#  define DEF_DIR		"$TMP"
# else
#  define DEF_DIR		"c:\\tmp"
# endif
#endif

#define TMPNAME1		"viXXXXXX"		/* put it in current dir */
#define TMPNAME2		"voXXXXXX"		/*  is there a better place? */
#ifdef NT
# define TMPNAMELEN		L_tmpnam
#else
# define TMPNAMELEN		10
#endif

#ifndef MAXMEM
# define MAXMEM			256				/* use up to 256Kbyte for buffer */
#endif
#ifndef MAXMEMTOT
# define MAXMEMTOT		0				/* decide in set_init */
#endif

#ifdef NT
# define BASENAMELEN	_MAX_PATH		/* length of base of file name */
#else
# define BASENAMELEN	8				/* length of base of file name */
#endif

/*
 * MSDOS Machine-dependent routines.
 */

#ifdef remove
# undef remove                   /* MSDOS remove()s when not readonly */
#endif
#define remove vim_remove

/* use chdir() that also changes the default drive */
#define chdir vim_chdir
